@@ -40,7 +40,7 @@ class DeleteUsersRequest(RpcRequest):
 	def get_Users(self):
 		return self.get_query_params().get('Users')
 
-	def set_Users(self,Users):
-		for i in range(len(Users)):	
-			if Users[i].get('Name') is not None:
-				self.add_query_param('User.' + str(i + 1) + '.Name' , Users[i].get('Name'))
+	def set_Users(self, Users):
+		for depth1 in range(len(Users)):
+			if Users[depth1].get('Name') is not None:
+				self.add_query_param('User.' + str(depth1 + 1) + '.Name', Users[depth1].get('Name'))
\ No newline at end of file
