@@ -49,6 +49,12 @@ class ListNodesRequest(RpcRequest):
 	def set_PageNumber(self,PageNumber):
 		self.add_query_param('PageNumber',PageNumber)
 
+	def get_Sequence(self):
+		return self.get_query_params().get('Sequence')
+
+	def set_Sequence(self,Sequence):
+		self.add_query_param('Sequence',Sequence)
+
 	def get_HostName(self):
 		return self.get_query_params().get('HostName')
 
